@@ -24,9 +24,16 @@
 #if defined(sun) && defined(__SVR4)
 #include <sys/byteorder.h>
 #else
+#ifdef _WIN32
+#define BIG_ENDIAN 'B'
+#define LITTLE_ENDIAN 'l'
+#define BYTE_ORDER LITTLE_ENDIAN
+#define bswap_32(val) ((((val) & 0x000000ffU) << 24) | (((val) & 0x0000ff00U) <<  8) | (((val) & 0x00ff0000U) >>  8) | (((val) & 0xff000000U) >> 24))
+#else
 #include <byteswap.h>
 #include <endian.h>
 #endif
+#endif
 #include <limits.h>
 #include <time.h>
 #include <stdlib.h>
