@@ -15,18 +15,13 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
 #ifndef _CAMEL_LOCK_H
 #define _CAMEL_LOCK_H
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus }*/
-
 #include <camel/camel-exception.h>
 
 /* for .lock locking, retry, delay and stale counts */
@@ -38,9 +33,11 @@ extern "C" {
 #define CAMEL_LOCK_RETRY (5) /* number of times to retry lock */
 #define CAMEL_LOCK_DELAY (2) /* delay between locking retries */
 
+G_BEGIN_DECLS
+
 typedef enum {
 	CAMEL_LOCK_READ,
-	CAMEL_LOCK_WRITE,
+	CAMEL_LOCK_WRITE
 } CamelLockType;
 
 /* specific locking strategies */
@@ -56,8 +53,6 @@ void camel_unlock_flock(int fd);
 int camel_lock_folder(const char *path, int fd, CamelLockType type, CamelException *ex);
 void camel_unlock_folder(const char *path, int fd);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* !_CAMEL_LOCK_H */
