@@ -27,9 +27,8 @@
 #include <errno.h>
 #include <string.h>
 
-#include <libedataserver/e-iconv.h>
-
 #include "camel-charset-map.h"
+#include "camel-iconv.h"
 #include "camel-mime-filter-charset.h"
 
 #define d(x)
@@ -67,7 +66,7 @@ camel_mime_filter_charset_finalize(CamelObject *o)
 	g_free(f->from);
 	g_free(f->to);
 	if (f->ic != (iconv_t) -1) {
-		e_iconv_close (f->ic);
+		camel_iconv_close (f->ic);
 		f->ic = (iconv_t) -1;
 	}
 }
@@ -83,7 +82,7 @@ reset(CamelMimeFilter *mf)
 	/* what happens with the output bytes if this resets the state? */
 	if (f->ic != (iconv_t) -1) {
 		buffer = buf;
-		e_iconv (f->ic, NULL, NULL, &buffer, &outlen);
+		camel_iconv (f->ic, NULL, NULL, &buffer, &outlen);
 	}
 }
 
@@ -107,7 +106,7 @@ complete(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out,
 	
 	if (inleft > 0) {
 		do {
-			converted = e_iconv (charset->ic, &inbuf, &inleft, &outbuf, &outleft);
+			converted = camel_iconv (charset->ic, &inbuf, &inleft, &outbuf, &outleft);
 			if (converted == (size_t) -1) {
 				if (errno == E2BIG) {
 					/*
@@ -147,7 +146,7 @@ complete(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out,
 	}
 	
 	/* flush the iconv conversion */
-	e_iconv (charset->ic, NULL, NULL, &outbuf, &outleft);
+	camel_iconv (charset->ic, NULL, NULL, &outbuf, &outleft);
 	
 	*out = mf->outbuf;
 	*outlen = mf->outsize - outleft;
@@ -181,7 +180,7 @@ filter(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out, s
 	inleft = len;
 	
 	do {
-		converted = e_iconv (charset->ic, &inbuf, &inleft, &outbuf, &outleft);
+		converted = camel_iconv (charset->ic, &inbuf, &inleft, &outbuf, &outleft);
 		if (converted == (size_t) -1) {
 			if (errno == E2BIG || errno == EINVAL)
 				break;
@@ -273,7 +272,7 @@ camel_mime_filter_charset_new_convert (const char *from_charset, const char *to_
 	
 	new = CAMEL_MIME_FILTER_CHARSET (camel_object_new (camel_mime_filter_charset_get_type ()));
 	
-	new->ic = e_iconv_open (to_charset, from_charset);
+	new->ic = camel_iconv_open (to_charset, from_charset);
 	if (new->ic == (iconv_t) -1) {
 		w(g_warning ("Cannot create charset conversion from %s to %s: %s",
 			     from_charset ? from_charset : "(null)",
