@@ -15,19 +15,14 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
 #ifndef _CAMEL_MIME_PARSER_H
 #define _CAMEL_MIME_PARSER_H
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
-
 #include <camel/camel-object.h>
 
 #include <camel/camel-mime-utils.h>
@@ -38,6 +33,8 @@ extern "C" {
 #define CAMEL_MIME_PARSER_CLASS(klass) CAMEL_CHECK_CLASS_CAST (klass, camel_mime_parser_get_type (), CamelMimeParserClass)
 #define CAMEL_IS_MIME_PARSER(obj)      CAMEL_CHECK_TYPE (obj, camel_mime_parser_get_type ())
 
+G_BEGIN_DECLS
+
 typedef struct _CamelMimeParserClass CamelMimeParserClass;
 
 /* NOTE: if you add more states, you may need to bump the
@@ -62,7 +59,7 @@ typedef enum _camel_mime_parser_state_t {
 	CAMEL_MIME_PARSER_STATE_HEADER_END,     /* dummy value */
 	CAMEL_MIME_PARSER_STATE_BODY_END,       /* end of message */
 	CAMEL_MIME_PARSER_STATE_MULTIPART_END,  /* end of multipart  */
-	CAMEL_MIME_PARSER_STATE_MESSAGE_END,    /* end of message */
+	CAMEL_MIME_PARSER_STATE_MESSAGE_END     /* end of message */
 } camel_mime_parser_state_t;
 
 struct _CamelMimeParser {
@@ -141,8 +138,6 @@ off_t camel_mime_parser_tell_start_headers (CamelMimeParser *parser);
 off_t camel_mime_parser_tell_start_from (CamelMimeParser *parser);
 off_t camel_mime_parser_tell_start_boundary(CamelMimeParser *parser);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* ! _CAMEL_MIME_PARSER_H */
