@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -26,22 +26,24 @@
 #endif
 
 #include <ctype.h>
+#include <errno.h>
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+
+#include <glib.h>
+#include <glib/gstdio.h>
 
-#include "camel-imap-utils.h"
-#include "camel-imap-summary.h"
-#include "camel-imap-store.h"
 #include "camel-folder.h"
 #include "camel-string-utils.h"
 #include "camel-utf8.h"
 
-#include <glib/gstdio.h>
+#include "camel-imap-store.h"
+#include "camel-imap-summary.h"
+#include "camel-imap-utils.h"
 
 #define d(x)
 
@@ -123,7 +125,7 @@ imap_namespace_decode (const char **in, struct _namespace **namespace)
 			}
 			
 			/* decode IMAP's modified UTF-7 into UTF-8 */
-			node->prefix = imap_mailbox_decode (astring, len);
+			node->prefix = imap_mailbox_decode ((const unsigned char *) astring, len);
 			g_free (astring);
 			if (!node->prefix) {
 				g_free (node);
@@ -373,6 +375,7 @@ imap_parse_list_response (CamelImapStore *store, const char *buf, int *flags, ch
 	
 	if (folder) {
 		char *astring;
+		char *mailbox;
 		
 		/* get the folder name */
 		word = imap_next_word (word);
@@ -382,9 +385,7 @@ imap_parse_list_response (CamelImapStore *store, const char *buf, int *flags, ch
 
 		*folder = astring;
 
-		char *mailbox;
-
-		mailbox = imap_mailbox_decode (astring, strlen (astring));
+		mailbox = imap_mailbox_decode ((const unsigned char *) astring, strlen (astring));
 		g_free (astring);
 		if (!mailbox)
 			return FALSE;
@@ -461,13 +462,44 @@ imap_parse_folder_name (CamelImapStore *store, const char *folder_name)
 	return paths;
 }
 
-char *
-imap_create_flag_list (guint32 flags)
+/*
+ * rename_flag
+ * Converts label flag name on server to name used in Evolution or back.
+ * It will never return NULL, it will return empty string, instead.
+ *
+ * @param flag Flag to rename.
+ * @param len Length of the flag name.
+ * @param server_to_evo if TRUE, then converting server names to evo's names, if FALSE then opposite.
+ */
+static const char *
+rename_label_flag (const char *flag, int len, gboolean server_to_evo)
 {
-	GString *gstr;
-	char *flag_list;
-	
-	gstr = g_string_new ("(");
+	int i;
+	const char *labels[] = {
+		"$Label1", "$Labelimportant",
+		"$Label2", "$Labelwork",
+		"$Label3", "$Labelpersonal",
+		"$Label4", "$Labeltodo",
+		"$Label5", "$Labellater",
+		NULL,      NULL };
+
+	/* It really can pass zero-length flags inside, in that case it was able
+	   to always add first label, which is definitely wrong. */
+	if (!len || !flag || !*flag)
+		return "";
+
+	for (i = 0 + (server_to_evo ? 0 : 1); labels[i]; i = i + 2) {
+		if (!g_ascii_strncasecmp (flag, labels[i], len))
+			return labels [i + (server_to_evo ? 1 : -1)];
+	}
+
+	return "";
+}
+
+char *
+imap_create_flag_list (guint32 flags, CamelMessageInfo *info, guint32 permanent_flags)
+{
+	GString *gstr = g_string_new ("(");
 
 	if (flags & CAMEL_MESSAGE_ANSWERED)
 		g_string_append (gstr, "\\Answered ");
@@ -479,66 +511,61 @@ imap_create_flag_list (guint32 flags)
 		g_string_append (gstr, "\\Flagged ");
 	if (flags & CAMEL_MESSAGE_SEEN)
 		g_string_append (gstr, "\\Seen ");
-	if (flags & CAMEL_MESSAGE_JUNK)
+	if ((flags & CAMEL_MESSAGE_JUNK) != 0 && (permanent_flags & CAMEL_MESSAGE_JUNK) != 0)
 		g_string_append (gstr, "Junk ");
-	if (flags & CAMEL_IMAP_MESSAGE_LABEL1)
-		g_string_append(gstr, "$Label1 ");
-	if (flags & CAMEL_IMAP_MESSAGE_LABEL2)
-		g_string_append(gstr, "$Label2 ");
-	if (flags & CAMEL_IMAP_MESSAGE_LABEL3)
-		g_string_append(gstr, "$Label3 ");
-	if (flags & CAMEL_IMAP_MESSAGE_LABEL4)
-		g_string_append(gstr, "$Label4 ");
-	if (flags & CAMEL_IMAP_MESSAGE_LABEL5)
-		g_string_append(gstr, "$Label5 ");
+	if ((flags & CAMEL_MESSAGE_NOTJUNK) != 0 && (permanent_flags & CAMEL_MESSAGE_NOTJUNK) != 0)
+		g_string_append (gstr, "NotJunk ");
+
+	/* send user flags to the server only when it supports it, otherwise store it locally only */
+	if (info && (permanent_flags & CAMEL_MESSAGE_USER) != 0) {
+		const CamelFlag *flag;
+		const char *name;
+
+		/* FIXME: All the custom flags are sent to the server. Not just the changed ones */
+		flag = camel_message_info_user_flags(info);
+		while (flag) {
+			if (flag->name && *flag->name) {
+				name = rename_label_flag (flag->name, strlen (flag->name), FALSE);
+
+				if (name && *name)
+					g_string_append (gstr, name);
+				else
+					g_string_append (gstr, flag->name);
+
+				g_string_append (gstr, " ");
+			}
+
+			flag = flag->next;
+		}
+	}
 
 	if (gstr->str[gstr->len - 1] == ' ')
 		gstr->str[gstr->len - 1] = ')';
 	else
 		g_string_append_c (gstr, ')');
 
-	flag_list = gstr->str;
-	g_string_free (gstr, FALSE);
-	return flag_list;
+	return g_string_free (gstr, FALSE);
 }
 
-guint32
-imap_label_to_flags(CamelMessageInfo *info)
-{
-	const char *label;
-	guint32 flags;
-
-	label = camel_message_info_user_tag(info, "label");
-	if (label == NULL)
-		flags = 0;
-	else if (!strcmp(label, "important"))
-		flags = CAMEL_IMAP_MESSAGE_LABEL1;
-	else if (!strcmp(label, "work"))
-		flags =  CAMEL_IMAP_MESSAGE_LABEL2;
-	else if (!strcmp(label, "personal"))
-		flags = CAMEL_IMAP_MESSAGE_LABEL3;
-	else if (!strcmp(label, "todo"))
-		flags = CAMEL_IMAP_MESSAGE_LABEL4;
-	else if (!strcmp(label, "later"))
-		flags = CAMEL_IMAP_MESSAGE_LABEL5;
-	else
-		flags = 0;
-
-	return flags;
-}
-
-guint32
-imap_parse_flag_list (char **flag_list_p)
+gboolean
+imap_parse_flag_list (char **flag_list_p, guint32 *flags_out, char **custom_flags_out)
 {
 	char *flag_list = *flag_list_p;
 	guint32 flags = 0;
 	int len;
-	
+	GString *custom_flags = NULL;
+	char *iter;
+
+	*flags_out = 0;
+
 	if (*flag_list++ != '(') {
 		*flag_list_p = NULL;
-		return 0;
+		return FALSE;
 	}
-	
+
+	if (custom_flags_out)
+		custom_flags = g_string_new ("");
+
 	while (*flag_list && *flag_list != ')') {
 		len = strcspn (flag_list, " )");
 		if (!g_ascii_strncasecmp (flag_list, "\\Answered", len))
@@ -554,32 +581,55 @@ imap_parse_flag_list (char **flag_list_p)
 		else if (!g_ascii_strncasecmp (flag_list, "\\Recent", len))
 			flags |= CAMEL_IMAP_MESSAGE_RECENT;
 		else if (!g_ascii_strncasecmp(flag_list, "\\*", len))
-			flags |= CAMEL_MESSAGE_USER|CAMEL_MESSAGE_JUNK|CAMEL_IMAP_MESSAGE_LABEL_MASK;
+			flags |= CAMEL_MESSAGE_USER|CAMEL_MESSAGE_JUNK|CAMEL_MESSAGE_NOTJUNK;
 		else if (!g_ascii_strncasecmp(flag_list, "Junk", len))
 			flags |= CAMEL_MESSAGE_JUNK;
-		else if (!g_ascii_strncasecmp(flag_list, "$Label1", len))
-			flags |= CAMEL_IMAP_MESSAGE_LABEL1;
-		else if (!g_ascii_strncasecmp(flag_list, "$Label2", len))
-			flags |= CAMEL_IMAP_MESSAGE_LABEL2;
-		else if (!g_ascii_strncasecmp(flag_list, "$Label3", len))
-			flags |= CAMEL_IMAP_MESSAGE_LABEL3;
-		else if (!g_ascii_strncasecmp(flag_list, "$Label4", len))
-			flags |= CAMEL_IMAP_MESSAGE_LABEL4;
-		else if (!g_ascii_strncasecmp(flag_list, "$Label5", len))
-			flags |= CAMEL_IMAP_MESSAGE_LABEL5;
-		
+		else if (!g_ascii_strncasecmp(flag_list, "NotJunk", len))
+			flags |= CAMEL_MESSAGE_NOTJUNK;
+		else if (!g_ascii_strncasecmp(flag_list, "$Label1", len) ||
+			 !g_ascii_strncasecmp(flag_list, "$Label2", len) ||
+			 !g_ascii_strncasecmp(flag_list, "$Label3", len) ||
+			 !g_ascii_strncasecmp(flag_list, "$Label4", len) ||
+			 !g_ascii_strncasecmp(flag_list, "$Label5", len)) {
+			if (custom_flags) {
+				g_string_append (custom_flags, rename_label_flag (flag_list, len, TRUE));
+				g_string_append_c (custom_flags, ' ');
+			}
+		} else {
+			iter = flag_list;
+			while (*iter != ' ' && *iter != ')') {
+				if (custom_flags)
+					g_string_append_c (custom_flags, *iter);
+				++iter;
+			}
+
+			if (custom_flags)
+				g_string_append_c (custom_flags, ' ');
+		}
+
 		flag_list += len;
 		if (*flag_list == ' ')
 			flag_list++;
 	}
-	
+
 	if (*flag_list++ != ')') {
 		*flag_list_p = NULL;
-		return 0;
+
+		if (custom_flags)
+			g_string_free (custom_flags, TRUE);
+
+		return FALSE;
 	}
-	
+
 	*flag_list_p = flag_list;
-	return flags;
+	*flags_out = flags;
+
+	if (custom_flags_out && custom_flags->len) {
+		*custom_flags_out = g_string_free (custom_flags, FALSE);
+	} else if (custom_flags)
+		g_string_free (custom_flags, TRUE);
+
+	return TRUE;
 }
 
 /*
@@ -966,6 +1016,19 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 		
 		/* size */
 		size = strtoul ((const char *) inptr, &p, 10);
+
+		/* check if the size wasn't negative */
+		if (p) {
+			while (inptr < p && *inptr != '-')
+				inptr++;
+
+			if (inptr < p)
+				size = 0;
+		}
+
+		if (size == 0)
+			goto exception;
+
 		inptr = (const unsigned char *) p;
 		
 		if (camel_content_type_is (ctype, "message", "rfc822")) {
@@ -976,7 +1039,7 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 			/* envelope */
 			imap_skip_list (&inptr);
 			
-			if (*inptr++ != ' ')
+			if (!inptr || *inptr++ != ' ')
 				goto exception;
 			
 			/* body */
@@ -984,14 +1047,14 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 				goto exception;
 			child->parent = ci;
 			
-			if (*inptr++ != ' ')
+			if (!inptr || *inptr++ != ' ')
 				goto exception;
 			
 			/* lines */
 			strtoul ((const char *) inptr, &p, 10);
 			inptr = (const unsigned char *) p;
 		} else if (camel_content_type_is (ctype, "text", "*")) {
-			if (*inptr++ != ' ')
+			if (!inptr || *inptr++ != ' ')
 				goto exception;
 			
 			/* lines */
@@ -1001,7 +1064,7 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 			/* body_type_basic */
 		}
 		
-		if (*inptr++ != ')')
+		if (!inptr || *inptr++ != ')')
 			goto exception;
 		
 		ci->type = ctype;
