@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -149,9 +149,8 @@ local_finalize(CamelObject * object)
 		folder->summary = NULL;
 	}
 
-	if (local_folder->search) {
+	if (local_folder->search)
 		camel_object_unref((CamelObject *)local_folder->search);
-	}
 
 	if (local_folder->index)
 		camel_object_unref((CamelObject *)local_folder->index);
@@ -307,16 +306,16 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 	if ((flags & CAMEL_STORE_FOLDER_CREATE) != 0) {
 		url = camel_url_copy (((CamelService *) parent_store)->url);
 		camel_url_set_fragment (url, full_name);
-	
-		fi = g_new0 (CamelFolderInfo, 1);
+
+		fi = camel_folder_info_new ();
 		fi->full_name = g_strdup (full_name);
 		fi->name = g_strdup (name);
 		fi->uri = camel_url_to_string (url, 0);
 		fi->unread = camel_folder_get_unread_message_count(folder);
 		fi->flags = CAMEL_FOLDER_NOCHILDREN;
-	
+
 		camel_url_free (url);
-	
+
 		camel_object_trigger_event(CAMEL_OBJECT (parent_store), "folder_created", fi);
 		camel_folder_info_free(fi);
 	}
